# Flask-Restaction

![travis-ci](https://api.travis-ci.org/guyskk/flask-restaction.svg)

Flask-Restaction is a web framwork born to create RESTful API

### You can do this Easily

- Create restful api 
- Validate inputs and Convert outputs
- Authorize and Permission control
- Auto generate res.js and document
- Support py3


### Install
    
    pip install flask-restaction


### Build Document

    cd docs
    make html

### Documents on Readthedocs

http://flask-restaction.readthedocs.org/zh/latest/

### Test

First, install test tools:

    pip install pytest
    pip install tox

Then, run tests

    py.test

    or

    tox

### Todos

- more tests
- more documents
- ...

## license 

MIT License